require 'sprockets/rails/task'

module Sprockets
  module Rails
    class Task
      def get_environment_assets
        ENV["ASSET_FILES"]
      end

      def input_assets
        get_environment_assets.gsub("[","").gsub("]","").split(",")
      end

      def specific_assets
        if app && input_assets.present?
          [assets.first] + input_assets
        else
          super
        end
      end

      def define
        namespace :assets do
          # Override this task change the loaded dependencies
          desc "Load asset compile environment"
          task :environment do
            # Load full Rails environment by default
            Rake::Task['environment'].invoke
          end

          desc "Compile all the assets named in config.assets.precompile"
          task :precompile => :environment do
            with_logger do
              manifest.compile(assets)
            end
          end

          desc "Remove old compiled assets"
          task :clean, [:keep] => :environment do |t, args|
            keep = Integer(args.keep || 2)
            with_logger do
              manifest.clean(keep)
            end
          end

          desc "Remove compiled assets"
          task :clobber => :environment do
            with_logger do
              manifest.clobber
              rm_rf cache_path if cache_path
            end
          end

          desc "Compile specific asset from ASSET_FILES variable"
          task :precompile_specific => :environment do
            with_logger do
              manifest.compile(specific_assets)
            end
          end
        end
      end
    end
  end
end
